SoundWaveAnimator class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDefaultPosition(
) → AnimationPosition -
override
-
getDefaultRadiusMultiplier(
) → double -
override
-
getOuterPadding(
) → double -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void -
override
-
shouldRepaint(
EffectAnimator oldAnimator) → bool -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited