StarburstParticle class

Constructors

StarburstParticle({required double angle, required double maxDistance, required double size, required double pulseRate, required double speed})

Properties

angle double
final
hashCode int
The hash code for this object.
no setterinherited
maxDistance double
final
pulseRate double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
speed double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited