DualParticleRayAnimator class

Implemented types

Constructors

DualParticleRayAnimator({int rayCount = 16, double rayLength = 70.0, double rayWidth = 2.2, double distanceFactor = 1.8, bool randomizeRays = true, double glowIntensity = 0.8, double glowRadius = 4.0, bool enableImplosion = true, bool enableExplosion = true, double speedFactor = 1.5})

Properties

distanceFactor double
final
enableExplosion bool
final
enableImplosion bool
final
glowIntensity double
final
glowRadius double
final
hashCode int
The hash code for this object.
no setterinherited
randomizeRays bool
final
rayCount int
final
rayLength double
final
rayWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedFactor double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator oldAnimator) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited