CircleBurstCleanAnimator class

Implemented types

Constructors

CircleBurstCleanAnimator({int particleCount = 18, bool enableHueTilt = true, double hueTiltRange = .30, double saturationBoost = 1.1, bool enableBloom = true, double bloomWidth = 2.5})

Properties

bloomWidth double
final
enableBloom bool
final
enableHueTilt bool
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
particleCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color baseColor, {double radiusMultiplier = 1, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited