DotBurstAnimator class

DotBurst animator dengan titik-titik yang meledak keluar dengan pola elastis dan ekor opsional.

Implemented types

Constructors

DotBurstAnimator({int dotCount = 24, double dotSize = 6, double dotTailFactor = 2.5, bool enableTail = true, double explosionScale = .75, double pulseEffect = 0.3, bool enableHueTilt = true, double hueTiltRange = .45, double saturationBoost = 1.2})

Properties

dotCount int
final
dotSize double
final
dotTailFactor double
final
enableHueTilt bool
final
enableTail bool
final
explosionScale double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
pulseEffect double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited