MagicDustAnimator class

Implemented types

Constructors

MagicDustAnimator({double speed = 1.0, int particleCount = 40, double baseSize = 3, double areaScale = .7, double gravity = 20, bool enableHueTilt = true, double hueTiltRange = .30, double saturationBoost = 1.1})

Properties

areaScale double
final
baseSize double
final
enableHueTilt bool
final
gravity double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
particleCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final
speed double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas cv, Size size, double p, Offset center, Color base, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited