MultiRingOrbitAnimator class

Implemented types

Constructors

MultiRingOrbitAnimator({int particlesPerRing = 10, int ringCount = 1, double circleRadius = 12, double ringGap = 10, double orbitMargin = 12, double rotations = 1.2, double fadeExtra = 14, double glowSigma = 4, bool enableHueTilt = true, double hueTiltRange = .35, double saturationBoost = 1.1})

Properties

circleRadius double
final
enableHueTilt bool
final
fadeExtra double
final
glowSigma double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
orbitMargin double
final
particlesPerRing int
final
ringCount int
final
ringGap double
final
rotations double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas cv, Size size, double p, Offset center, Color baseColor, {double radiusMultiplier = 1, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited