PixelExplosionAnimator class

Implemented types

Constructors

PixelExplosionAnimator({double speed = 1.0, bool enableHueTilt = true, double hueTiltRange = .30, double saturationBoost = 1.1})

Properties

enableHueTilt bool
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final
speed double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double p, Offset center, Color base, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited