PulseWaveAnimator class

Gelombang pulsa melingkar dengan partikel yang muncul dan menghilang.

Implemented types

Constructors

PulseWaveAnimator({int ringCount = 3, int particlesPerRing = 16, double particleRadius = 4, double waveScale = 0.8, double waveThickness = 0.15, double waveSpeed = 0.8, bool enableHueTilt = true, double hueTiltRange = 0.3, double saturationBoost = 1.1})

Properties

enableHueTilt bool
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
particleRadius double
final
particlesPerRing int
final
ringCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final
waveScale double
final
waveSpeed double
final
waveThickness double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited