RayBurstMovingAnimator class

Ray Burst animator dengan garis-garis yang memancar dari pusat. Ray Burst animator dengan garis-garis yang memancar dan bergerak keluar dari pusat.

Implemented types

Constructors

RayBurstMovingAnimator({int rayCount = 16, double lineWidth = 2.0, double lineLength = 30.0, double rayLength = 0.7, double expansionRate = 1.2, bool enableHueTilt = true, double hueTiltRange = .45, double saturationBoost = 1.2})

Properties

enableHueTilt bool
final
expansionRate double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
lineLength double
final
lineWidth double
final
rayCount int
final
rayLength double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited