ShapeExplosionAnimator class

Radial burst partikel (lingkaran + ekor) dengan opsi gradasi HSV.

Implemented types

Constructors

ShapeExplosionAnimator({int particleCount = 18, double circleRadius = 6, double tailFactor = 3, double explosionScale = .7, bool useUniformAngle = true, bool enableHueTilt = true, double hueTiltRange = .35, double saturationBoost = 1.1})

Properties

circleRadius double
final
enableHueTilt bool
final
explosionScale double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
particleCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final
tailFactor double
final
useUniformAngle bool
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited