SpiralExplosionAnimator class

Radial burst ala firework, tetapi memakai shape (circle + tail) ── cocok sebagai penanda netral “item berhasil di‑drop”. Spiral burst partikel dengan rotasi dan pengurangan ukuran.

Implemented types

Constructors

SpiralExplosionAnimator({int particleCount = 24, double circleRadius = 5, double tailFactor = 2.5, double explosionScale = .65, double spiralTightness = 0.3, double rotationSpeed = 2.0, bool enableHueTilt = true, double hueTiltRange = .5, double saturationBoost = 1.2})

Properties

circleRadius double
final
enableHueTilt bool
final
explosionScale double
final
hashCode int
The hash code for this object.
no setterinherited
hueTiltRange double
final
particleCount int
final
rotationSpeed double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturationBoost double
final
spiralTightness double
final
tailFactor double
final

Methods

getDefaultPosition() AnimationPosition
override
getDefaultRadiusMultiplier() double
override
getOuterPadding() double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void
override
shouldRepaint(EffectAnimator old) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited