RadialFireworkAnimator class
Animator untuk efek firework radial yang super energetik dan menarik bagi anak-anak
- Implemented types
Constructors
- RadialFireworkAnimator({double fadeInRelativeDuration = 0.15, double stretchRelativeDuration = 0.25, double closeRelativeDuration = 0.20, double fadeOutRelativeDuration = 0.40, int elementCount = 12, double circleRadius = 5.0, double lineLength = 40.0, double finalScale = 1.6, bool enableSparkles = true, bool enableColorShift = true, bool enableExtraBounce = true})
Properties
- circleRadius → double
-
final
- closeRelativeDuration → double
-
final
- elementCount → int
-
final
- enableColorShift → bool
-
final
- enableExtraBounce → bool
-
final
- enableSparkles → bool
-
final
- fadeInRelativeDuration → double
-
final
- fadeOutRelativeDuration → double
-
final
- finalScale → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineLength → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stretchRelativeDuration → double
-
final
Methods
-
getDefaultPosition(
) → AnimationPosition -
override
-
getDefaultRadiusMultiplier(
) → double -
override
-
getOuterPadding(
) → double -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void -
override
-
shouldRepaint(
EffectAnimator oldAnimator) → bool -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited