AnimationType enum
Values
- radialFirework → const AnimationType
- firework → const AnimationType
- ripple → const AnimationType
- spiral → const AnimationType
- shapeExplosion → const AnimationType
- shapeImplode → const AnimationType
- shapeRetractImplode → const AnimationType
- shapeExplodeOut → const AnimationType
- orbitBloom → const AnimationType
- circleBurst → const AnimationType
- circleBurstClean → const AnimationType
- magicDust → const AnimationType
- pixelExplosion → const AnimationType
- pulseWave → const AnimationType
- dotBurst → const AnimationType
- dotAbsorbBurst → const AnimationType
- rayLine → const AnimationType
- circleOrbitSequential → const AnimationType
- multiRingOrbit → const AnimationType
- sequentialRingOrbit → const AnimationType
- flowerCircle → const AnimationType
- magicalFlower → const AnimationType
- magicalOrbitDots → const AnimationType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AnimationType> - A constant List of the values in this enum, in order of their declaration.