AnimationUtils class
Kumpulan fungsi & helper yang dipakai bersama oleh semua animator.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bouncyEaseOut(
double t) → double -
drawSparkles(
{required Canvas canvas, required Offset center, required double progress, required Color baseColor, required Random random, required double maxDistance, required int sparkleCount, required bool foreground}) → void -
Sparkle util (set
foreground=trueuntuk bintang terang di depan). -
drawStar(
Canvas canvas, Offset center, double size, Color color) → void -
easeIn(
double t) → double -
easeInOut(
double t) → double -
easeOut(
double t) → double -
elasticInOut(
double t) → double -
elasticOut(
double t) → double -
random(
[int seed = _defaultSeed]) → Random -
shiftHue(
Color color, double hueShift, {double saturationFactor = 1.0, double lightnessFactor = 1.0}) → Color