MagicalFlowerAnimator class
Natural flower animator yang membuat bunga alami seperti Hibiscus/Petunia di sekitar widget. Magical aesthetic flower animator dengan detail tinggi dan efek berkilau.
- Implemented types
Constructors
- MagicalFlowerAnimator({int petalCount = 5, double petalWidth = 50.0, double petalLength = 70.0, double flowerScale = 1.5, double centerScale = 0.3, double petalCurve = 0.4, double petalOverlap = 0.2, double rotationSpeed = 0.1, bool enableGlowEffect = true, bool enableSparkles = true, bool enablePatternDetail = true, bool enablePetalGradient = true, int sparkleCount = 12, bool enableHueTilt = true, double hueTiltRange = 0.15, double saturationBoost = 1.2, Color centerColor = const Color(0xFF55BBAA), Color accentColor = const Color(0xFFFFFFFF)})
Properties
- accentColor → Color
-
final
- centerColor → Color
-
final
- centerScale → double
-
final
- enableGlowEffect → bool
-
final
- enableHueTilt → bool
-
final
- enablePatternDetail → bool
-
final
- enablePetalGradient → bool
-
final
- enableSparkles → bool
-
final
- flowerScale → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hueTiltRange → double
-
final
- petalCount → int
-
final
- petalCurve → double
-
final
- petalLength → double
-
final
- petalOverlap → double
-
final
- petalWidth → double
-
final
- rotationSpeed → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturationBoost → double
-
final
- sparkleCount → int
-
final
Methods
-
getDefaultPosition(
) → AnimationPosition -
override
-
getDefaultRadiusMultiplier(
) → double -
override
-
getOuterPadding(
) → double -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, double progress, Offset center, Color color, {double radiusMultiplier = 1.0, Offset positionOffset = Offset.zero}) → void -
override
-
shouldRepaint(
EffectAnimator old) → bool -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited