EffectAnimation class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- EffectAnimation
- Available extensions
Constructors
- EffectAnimation({Key? key, required Widget child, Color effectColor = const Color(0xFF8BB3C5), Duration duration = const Duration(milliseconds: 2400), bool repeatWhenDrag = true, bool autoAnimate = false, AnimationType animationType = AnimationType.firework, double? radiusMultiplier, AnimationPosition position = AnimationPosition.outside, Offset? customOffset, EffectAnimationController? controller, bool touchEnabled = true})
-
const
Properties
- animationType → AnimationType
-
final
- autoAnimate → bool
-
final
- child → Widget
-
final
- controller → EffectAnimationController?
-
final
- customOffset → Offset?
-
final
- duration → Duration
-
final
- effectColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- position → AnimationPosition
-
final
- radiusMultiplier → double?
-
final
- repeatWhenDrag → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- touchEnabled → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< EffectAnimation> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withEffectAnimation(
{Color effectColor = const Color(0xFF8BB3C5), Duration duration = const Duration(milliseconds: 2400), bool repeatWhenDrag = true, bool autoAnimate = false, AnimationType animationType = AnimationType.firework, double? radiusMultiplier, AnimationPosition position = AnimationPosition.outside, Offset? customOffset, EffectAnimationController? controller, bool touchEnabled = true}) → Widget -
Available on Widget, provided by the EffectAnimationExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited